==> scala-k8s-client_sjs1_2.13-0.8.2-sources.jar: pointers/io/k8s/api/core/v1/EphemeralContainerPointer.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.client._

/** Pointer for EphemeralContainer */
final case class EphemeralContainerPointer(currentPath: PointerPath = PointerPath()) extends Pointer[io.k8s.api.core.v1.EphemeralContainer] {
  def name : Pointer.Plain[String] = Pointer.Plain(currentPath / s"name")
  def readinessProbe :  io.k8s.api.core.v1.ProbePointer = io.k8s.api.core.v1.ProbePointer(currentPath / s"readinessProbe")
  def livenessProbe :  io.k8s.api.core.v1.ProbePointer = io.k8s.api.core.v1.ProbePointer(currentPath / s"livenessProbe")
  def lifecycle :  io.k8s.api.core.v1.LifecyclePointer = io.k8s.api.core.v1.LifecyclePointer(currentPath / s"lifecycle")
  def image : Pointer.Plain[String] = Pointer.Plain(currentPath / s"image")
  def stdinOnce : Pointer.Plain[Boolean] = Pointer.Plain(currentPath / s"stdinOnce")
  def ports : ListPointer[io.k8s.api.core.v1.ContainerPort] = ListPointer(currentPath / s"ports")
  def startupProbe :  io.k8s.api.core.v1.ProbePointer = io.k8s.api.core.v1.ProbePointer(currentPath / s"startupProbe")
  def command : ListPointer[String] = ListPointer(currentPath / s"command")
  def terminationMessagePolicy : Pointer.Plain[String] = Pointer.Plain(currentPath / s"terminationMessagePolicy")
  def targetContainerName : Pointer.Plain[String] = Pointer.Plain(currentPath / s"targetContainerName")
  def stdin : Pointer.Plain[Boolean] = Pointer.Plain(currentPath / s"stdin")
  def terminationMessagePath : Pointer.Plain[String] = Pointer.Plain(currentPath / s"terminationMessagePath")
  def resources :  io.k8s.api.core.v1.ResourceRequirementsPointer = io.k8s.api.core.v1.ResourceRequirementsPointer(currentPath / s"resources")
  def envFrom : ListPointer[io.k8s.api.core.v1.EnvFromSource] = ListPointer(currentPath / s"envFrom")
  def volumeDevices : ListPointer[io.k8s.api.core.v1.VolumeDevice] = ListPointer(currentPath / s"volumeDevices")
  def args : ListPointer[String] = ListPointer(currentPath / s"args")
  def tty : Pointer.Plain[Boolean] = Pointer.Plain(currentPath / s"tty")
  def imagePullPolicy : Pointer.Plain[String] = Pointer.Plain(currentPath / s"imagePullPolicy")
  def workingDir : Pointer.Plain[String] = Pointer.Plain(currentPath / s"workingDir")
  def volumeMounts : ListPointer[io.k8s.api.core.v1.VolumeMount] = ListPointer(currentPath / s"volumeMounts")
  def env : ListPointer[io.k8s.api.core.v1.EnvVar] = ListPointer(currentPath / s"env")
  def securityContext :  io.k8s.api.core.v1.SecurityContextPointer = io.k8s.api.core.v1.SecurityContextPointer(currentPath / s"securityContext")
}

==> scala-k8s-client_sjs1_3-0.16.4-sources.jar: pointers/io/k8s/api/core/v1/EphemeralContainerPointer.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.client._

/** Pointer for EphemeralContainer */
final case class EphemeralContainerPointer(currentPath: PointerPath = PointerPath()) extends Pointer[io.k8s.api.core.v1.EphemeralContainer] {
  def name : Pointer.Plain[String] = Pointer.Plain(currentPath / s"name")
  def readinessProbe :  io.k8s.api.core.v1.ProbePointer = io.k8s.api.core.v1.ProbePointer(currentPath / s"readinessProbe")
  def livenessProbe :  io.k8s.api.core.v1.ProbePointer = io.k8s.api.core.v1.ProbePointer(currentPath / s"livenessProbe")
  def lifecycle :  io.k8s.api.core.v1.LifecyclePointer = io.k8s.api.core.v1.LifecyclePointer(currentPath / s"lifecycle")
  def image : Pointer.Plain[String] = Pointer.Plain(currentPath / s"image")
  def resizePolicy : ListPointer[io.k8s.api.core.v1.ContainerResizePolicy] = ListPointer(currentPath / s"resizePolicy")
  def stdinOnce : Pointer.Plain[Boolean] = Pointer.Plain(currentPath / s"stdinOnce")
  def ports : ListPointer[io.k8s.api.core.v1.ContainerPort] = ListPointer(currentPath / s"ports")
  def startupProbe :  io.k8s.api.core.v1.ProbePointer = io.k8s.api.core.v1.ProbePointer(currentPath / s"startupProbe")
  def command : ListPointer[String] = ListPointer(currentPath / s"command")
  def terminationMessagePolicy : Pointer.Plain[String] = Pointer.Plain(currentPath / s"terminationMessagePolicy")
  def targetContainerName : Pointer.Plain[String] = Pointer.Plain(currentPath / s"targetContainerName")
  def restartPolicy : Pointer.Plain[String] = Pointer.Plain(currentPath / s"restartPolicy")
  def stdin : Pointer.Plain[Boolean] = Pointer.Plain(currentPath / s"stdin")
  def terminationMessagePath : Pointer.Plain[String] = Pointer.Plain(currentPath / s"terminationMessagePath")
  def resources :  io.k8s.api.core.v1.ResourceRequirementsPointer = io.k8s.api.core.v1.ResourceRequirementsPointer(currentPath / s"resources")
  def envFrom : ListPointer[io.k8s.api.core.v1.EnvFromSource] = ListPointer(currentPath / s"envFrom")
  def volumeDevices : ListPointer[io.k8s.api.core.v1.VolumeDevice] = ListPointer(currentPath / s"volumeDevices")
  def args : ListPointer[String] = ListPointer(currentPath / s"args")
  def tty : Pointer.Plain[Boolean] = Pointer.Plain(currentPath / s"tty")
  def imagePullPolicy : Pointer.Plain[String] = Pointer.Plain(currentPath / s"imagePullPolicy")
  def workingDir : Pointer.Plain[String] = Pointer.Plain(currentPath / s"workingDir")
  def volumeMounts : ListPointer[io.k8s.api.core.v1.VolumeMount] = ListPointer(currentPath / s"volumeMounts")
  def env : ListPointer[io.k8s.api.core.v1.EnvVar] = ListPointer(currentPath / s"env")
  def securityContext :  io.k8s.api.core.v1.SecurityContextPointer = io.k8s.api.core.v1.SecurityContextPointer(currentPath / s"securityContext")
}
